@@ -57,29 +57,7 @@ class Assets(WMLResource):
 
              >>> asset_details = client.data_assets.get_details(asset_uid)
         """
-        Assets._validate_type(asset_uid, u'asset_uid', STR_TYPE, False)
-
-        if asset_uid:
-            response = requests.get(self._client.service_instance._href_definitions.get_data_asset_href(asset_uid), params=self._client._params(),
-                                    headers=self._client._get_headers())
-
-            return self._get_required_element_from_response(self._handle_response(200, u'get asset details', response))
-
-        else:
-            href = self._client.service_instance._href_definitions.get_search_asset_href()
-
-            data = {
-                "query": "*:*"
-            }
-
-            response = requests.post(href,
-                                    json=data,
-                                    params=self._client._params(),
-                                    headers=self._client._get_headers())
-
-            return {'resources': [
-                self._get_required_element_from_response(x)
-                for x in self._handle_response(200, u'get assets details', response)['results']]}
+        return self._get_asset_based_resource(asset_uid, 'data_asset', self._get_required_element_from_response)
 
     @docstring_parameter({'str_type': STR_TYPE_NAME})
     def create(self, name, file_path):
