@@ -20,7 +20,7 @@ except ImportError:
 
 DEFAULT_SAMPLE_SIZE_LIMIT = 1073741824  # 1GB in Bytes is verified later by _set_sample_size_limit
 DEFAULT_REDUCED_SAMPLE_SIZE_LIMIT = 104857600  # 100MB in bytes
-DEFAULT_SAMPLING_TYPE = SamplingTypes.FIRST_N_RECORDS
+DEFAULT_SAMPLING_TYPE = SamplingTypes.FIRST_VALUES
 
 
 class ExperimentIterableDataset(IterableDataset):
@@ -208,7 +208,7 @@ class ExperimentIterableDataset(IterableDataset):
                 self.sample_size_limit = DEFAULT_REDUCED_SAMPLE_SIZE_LIMIT      # 100MB in bytes
 
             if self.enable_sampling is False:
-                self.sample_size_limit = None
+                self.sample_size_limit = 100*1024*1024*1024 #100 GB, temporary fix 
         else:
             self.sample_size_limit = sample_size_limit
 
@@ -252,7 +252,7 @@ class ExperimentIterableDataset(IterableDataset):
         """Iterate over Flight Dataset."""
         if self.authorized:
             if self.enable_sampling:
-                if self.sampling_type == SamplingTypes.FIRST_N_RECORDS:
+                if self.sampling_type == SamplingTypes.FIRST_VALUES:
                     return self.connection.iterable_read()
                 else:
                     self.connection.enable_subsampling = True
