@@ -165,7 +165,7 @@ class WMLEngine(BaseEngine):
         # end of section
 
         # pass fairness info for Cloud or CP4D 4.5
-        if self._wml_client.CLOUD_PLATFORM_SPACES or self._wml_client.ICP_45:
+        if self._wml_client.CLOUD_PLATFORM_SPACES or self._wml_client.ICP_45 or self._wml_client.ICP_46:
             if self._auto_pipelines_parameters.get('fairness_info') is not None:
                 self._wml_pipeline_metadata[self._wml_client.pipelines.ConfigurationMetaNames.DOCUMENT][
                     'pipelines'][0]['nodes'][0]['parameters']['optimization'][
@@ -489,7 +489,7 @@ class WMLEngine(BaseEngine):
                     'runtimes'][0]['version'] = self._auto_pipelines_parameters['obm_pod_version']
 
             else:
-                if self._wml_client.ICP_45:
+                if self._wml_client.ICP_45 or self._wml_client.ICP_46:
                     template_id = 'spark-3.2-automl-cp4d-template'
                 elif not (self._wml_client.ICP_30 or self._wml_client.ICP_35):
                     template_id = 'spark-3.0.0-automl-cp4d-template'
