@@ -38,7 +38,7 @@ from ibm_watson_machine_learning.utils.autoai.wsd_ui import (
     save_computed_pipelines_for_ui, save_experiment_for_ui, save_metadata_for_ui)
 from ibm_watson_machine_learning.utils.autoai.connection import validate_source_data_connections, \
     validate_results_data_connection
-from ibm_watson_machine_learning.utils import DisableWarningsLogger
+from ibm_watson_machine_learning.utils import DisableWarningsLogger, WMLClientError
 from ibm_watson_machine_learning.messages.messages import Messages
 from .base_auto_pipelines import BaseAutoPipelines
 
@@ -353,7 +353,9 @@ class RemoteAutoPipelines(BaseAutoPipelines):
         >>>     background_mode=False)
         """
         if self.params.get('data_join_graph'):
-            if self._workspace.wml_client.ICP:
+            if self._workspace.wml_client.ICP_46:
+                raise WMLClientError(Messages.get_message(message_id="obm_removal_message_cpd"))
+            elif self._workspace.wml_client.ICP:
                 print(Messages.get_message(message_id="obm_deprecation_message_cpd"))
             #else:
             #    print(Messages.get_message(message_id="obm_deprecation_message_cloud"))
@@ -589,7 +591,9 @@ class RemoteAutoPipelines(BaseAutoPipelines):
         >>> remote_optimizer.get_run_details()
         """
         if not _internal and self.params.get('data_join_graph'):
-            if self._workspace.wml_client.ICP:
+            if self._workspace.wml_client.ICP_46:
+                raise WMLClientError(Messages.get_message(message_id="obm_removal_message_cpd"))
+            elif self._workspace.wml_client.ICP:
                 print(Messages.get_message(message_id="obm_deprecation_message_cpd"))
             #else:
             #    print(Messages.get_message(message_id="obm_deprecation_message_cloud"))
