@@ -875,6 +875,11 @@ class DataConnection(BaseDataConnection):
                                                                    number_of_batch_rows=number_of_batch_rows,
                                                                    _return_subsampling_stats=_return_subsampling_stats)
 
+        # create data statistics if data were not downloaded with flight:
+        if not isinstance(data, tuple) and _return_subsampling_stats:
+            data = (data, {"data_batch_size": sys.getsizeof(data),
+                           "data_batch_no_rows": len(data)})
+
         if binary:
             return data
 
