@@ -1177,7 +1177,7 @@ class FlightConnection:
             return self.regression_random_sampling
         elif self.sampling_type == SamplingTypes.STRATIFIED and self.learning_type in stratified_sampling_pred_types:
             return self.stratified_subsampling
-        elif self.sampling_type == SamplingTypes.TRUNCATE and self.learning_type in truncate_sampling_pred_types:
+        elif self.sampling_type == SamplingTypes.LAST_VALUES and self.learning_type in truncate_sampling_pred_types:
             return self.truncate_sampling
         else:
             raise InvalidSamplingType(self.sampling_type, self.learning_type)
