@@ -115,7 +115,8 @@ class Pipelines(WMLResource):
                   }
                 ]
               }
-        if self._client.CLOUD_PLATFORM_SPACES or self._client.ICP_35 or self._client.ICP_40 or self._client.ICP_45:
+        if self._client.CLOUD_PLATFORM_SPACES or self._client.ICP_35 or self._client.ICP_40 or \
+                self._client.ICP_45 or self._client.ICP_46:
             if self.ConfigurationMetaNames.COMMAND in meta_props:
                 doc["pipelines"][0]["nodes"][0]["parameters"]["command"] = meta_props[self.ConfigurationMetaNames.COMMAND]
             if self.ConfigurationMetaNames.RUNTIMES in meta_props:
@@ -199,7 +200,8 @@ class Pipelines(WMLResource):
             else:
                 raise WMLClientError("It is mandatory to set the space/project id. Use client.set.default_space(<SPACE_UID>)/client.set.default_project(<PROJECT_UID>) to proceed.")
 
-        if self._client.CLOUD_PLATFORM_SPACES or self._client.ICP_35 or self._client.ICP_40 or self._client.ICP_45:
+        if self._client.CLOUD_PLATFORM_SPACES or self._client.ICP_35 or self._client.ICP_40 or \
+                self._client.ICP_45 or self._client.ICP_46:
             if self._client.default_space_id is not None:
                 pipeline_meta['space_id'] = self._client.default_space_id
             elif self._client.default_project_id is not None:
@@ -282,7 +284,7 @@ class Pipelines(WMLResource):
                 pipeline_details = self._handle_response(201, u'creating new pipeline', creation_response)
                 return WMLResource._wsd_get_required_element_from_response(self, pipeline_details)
 
-            elif self._client.ICP_35 or self._client.ICP_40 or self._client.ICP_45:
+            elif self._client.ICP_35 or self._client.ICP_40 or self._client.ICP_45 or self._client.ICP_46:
                 creation_response = requests.post(
                     self._client.service_instance._href_definitions.get_pipelines_href(),
                     headers=self._client._get_headers(),
@@ -317,7 +319,7 @@ class Pipelines(WMLResource):
         Pipelines._validate_type(pipeline_uid, u'pipeline_uid', STR_TYPE, False)
 
         if not any([self._client.ICP_30, self._client.CLOUD_PLATFORM_SPACES, self._client.ICP_35, self._client.ICP_40,
-                    self._client.ICP_45]):
+                    self._client.ICP_45, self._client.ICP_46]):
             raise WMLClientError(
                 u'Revision support is not there in this version WML server. It is supported only from 3.1.0 onwards.')
         else:
@@ -495,7 +497,7 @@ class Pipelines(WMLResource):
         Pipelines._validate_type(pipeline_uid, u'pipeline_uid', STR_TYPE, True)
         Pipelines._validate_type(rev_uid, u'rev_uid', int, True)
         if not any([self._client.ICP_30, self._client.CLOUD_PLATFORM_SPACES, self._client.ICP_35, self._client.ICP_40,
-                    self._client.ICP_45]):
+                    self._client.ICP_45, self._client.ICP_46]):
             raise WMLClientError(
                 'Not supported. Revisions APIs are supported only for IBM Cloud Pak® for Data 3.0 and above.')
         else:
@@ -632,7 +634,8 @@ class Pipelines(WMLResource):
             self._client._check_if_either_is_set()
 
             pipeline_resources = self.get_details(limit=limit)[u'resources']
-            if self._client.CLOUD_PLATFORM_SPACES or self._client.ICP_35 or self._client.ICP_40 or self._client.ICP_45:
+            if self._client.CLOUD_PLATFORM_SPACES or self._client.ICP_35 or self._client.ICP_40 or \
+                    self._client.ICP_45 or self._client.ICP_46:
                 pipeline_values = [(m[u'metadata'][u'id'], m[u'metadata'][u'name'], m[u'metadata'][u'created_at']) for m
                                    in pipeline_resources]
 
@@ -667,7 +670,7 @@ class Pipelines(WMLResource):
         Pipelines._validate_type(pipeline_uid, u'pipeline_uid', STR_TYPE, True)
 
         if not any([self._client.ICP_30, self._client.CLOUD_PLATFORM_SPACES, self._client.ICP_35, self._client.ICP_40,
-                    self._client.ICP_45]):
+                    self._client.ICP_45, self._client.ICP_46]):
             raise WMLClientError(
                 u'Revision support is not there in this WML server. It is supported only from 3.1.0 onwards.')
         else:
@@ -720,7 +723,8 @@ class Pipelines(WMLResource):
                     * Space id is mandatory for move action\n
 
         """
-        if any([self._client.WSD, self._client.CLOUD_PLATFORM_SPACES, self._client.ICP_35, self._client.ICP_40, self._client.ICP_45]):
+        if any([self._client.WSD, self._client.CLOUD_PLATFORM_SPACES, self._client.ICP_35, self._client.ICP_40,
+                self._client.ICP_45, self._client.ICP_46]):
             raise WMLClientError(" Clone pipeline operation is not supported. ")
         artifact = str_type_conv(pipeline_uid)
         Pipelines._validate_type(artifact, 'exp_id', STR_TYPE, True)
