@@ -289,7 +289,7 @@ class Repository(WMLResource):
         return self._client.pipelines.store(meta_props)
 
     @docstring_parameter({'str_type': STR_TYPE_NAME})
-    def store_model(self, model, meta_props=None, training_data=None, training_target=None, pipeline=None, feature_names=None, label_column_names=None,subtrainingId=None):
+    def store_model(self, model, meta_props=None, training_data=None, training_target=None, pipeline=None, feature_names=None, label_column_names=None,subtrainingId=None, round_number=None):
         """
                 Create a model.
 
@@ -338,6 +338,9 @@ class Repository(WMLResource):
                     #. **label_column_names**:  Label column names of the trained Scikit-Learn/XGBoost models.\n
                        **type**: numpy.ndarray and list\n
 
+                    #. **round_number**: round number of a Federated Learning experiment that has been configured to save intermediate models.  This applies when model is a training id.  
+                       **type**: int
+
 
 
                 **Output**
@@ -408,7 +411,7 @@ class Repository(WMLResource):
                     >>> stored_model_details = client.repository.store_model(trained_model_guid, meta_props=metadata, training_data=None)
             """
 
-        return self._client._models.store(model, meta_props=meta_props, training_data=training_data, training_target=training_target, pipeline=pipeline, feature_names=feature_names, label_column_names=label_column_names,subtrainingId=subtrainingId)
+        return self._client._models.store(model, meta_props=meta_props, training_data=training_data, training_target=training_target, pipeline=pipeline, feature_names=feature_names, label_column_names=label_column_names,subtrainingId=subtrainingId,round_number=round_number)
 
     @docstring_parameter({'str_type': STR_TYPE_NAME})
     def clone(self, artifact_id, space_id=None, action="copy", rev_id=None):
@@ -903,10 +906,10 @@ class Repository(WMLResource):
         elif res['function'] is True:
             return self._client._functions.download(artifact_uid, filename, rev_uid)
         elif not self._client.CLOUD_PLATFORM_SPACES and not self._client.ICP_35 and not self._client.ICP_40  \
-                and not self._client.ICP_45 and res['library'] is True:
+                and not self._client.ICP_45 and not self._client.ICP_46 and res['library'] is True:
             return self._client.runtimes.download_library(artifact_uid, filename)
         elif not self._client.CLOUD_PLATFORM_SPACES and not self._client.ICP_35 and not self._client.ICP_40 \
-                and not self._client.ICP_45 and res['runtime'] is True:
+                and not self._client.ICP_45 and not self._client.ICP_46 and res['runtime'] is True:
             return self._client.runtimes.download_configuration(artifact_uid, filename)
         else:
             raise WMLClientError('Unexpected type of artifact to download or Artifact with artifact_uid: \'{}\' does not exist.'.format(artifact_uid) )
