@@ -750,3 +750,24 @@ def prepare_interaction_props_for_cos(source_params: dict, file_name: str) -> di
         interaction_properties["file_format"] = file_format
 
     return interaction_properties
+
+
+def modify_details_for_script_and_shiny(details_from_get: dict) -> dict:
+    """
+    Add the href and id of and asset to the same position as it is returned from the POST method
+    it allows the `get_id`/`get_href` method to work with details returned by GET method.
+    Parameters
+    ---
+    details_from_get: dict, required
+        Details of script/shiny app acquired using GET method.
+    Returns
+    ---
+    Dictionary with 'guid' and 'href' key added to 'metadata'.
+    """
+    try:
+        details_from_get[u'metadata'][u'href'] = details_from_get[u'href']
+        details_from_get[u'metadata'][u'guid'] = details_from_get[u'metadata'][u'asset_id']
+    except KeyError:
+        pass
+
+    return details_from_get
